from datetime import datetime

def flarum_to_datetime(flarum_dt: str) -> datetime:
    """
        Converts Flarum's datetime string to Python's datetime object.
        Doesn't convert if the parameter is already a datetime object.
        
        Flarum's datetime format is `%Y-%m-%dT%H:%M:%S%z`
    """

    if type(flarum_dt) == datetime:
        return flarum_dt

    return datetime.strptime(flarum_dt, '%Y-%m-%dT%H:%M:%S%z')


def datetime_to_flarum(dt: datetime) -> str:
    """
        Converts Python's datetime object to Flarum's datetime string.
        Doesn't convert if the parameter is already a string.
        
        Flarum's datetime format is `%Y-%m-%dT%H:%M:%S%z`
    """

    if type(dt) == str:
        return dt

    return dt.strftime('%Y-%m-%dT%H:%M:%S%z')



class FlarumError(Exception):
    """
        Base exception for Flarum response errors.
    """

    pass

class FlarumPermissionError(FlarumError):
    """
        Gets raised when you don't have permission to perform a certain forum action.
    """

    pass

class FlarumUnauthenticatedError(FlarumError):
    """
        This exception is raised when the Flarum user is not authenticated
        and tries to perform authenticated-only operation (such as creating a discussion).
    """

    pass


#
# MAIN:
#
from pyflarum.classes.FlarumSession import FlarumSession
FlarumSession
from pyflarum.classes.FlarumMyUser import FlarumMyUser
FlarumMyUser


#
# FORUM:
#
from pyflarum.classes.flarum.FlarumForum import FlarumForum
FlarumForum


#
# USERS:
#
from pyflarum.classes.flarum.FlarumUser import FlarumUser
FlarumUser

from pyflarum.classes.flarum.FlarumUsers import FlarumUsers
FlarumUsers


#
# GROUPS:
#
from pyflarum.classes.flarum.FlarumGroups import FlarumGroup, FlarumGroups
FlarumGroup
FlarumGroups


#
# DISCUSSIONS:
#
from pyflarum.classes.flarum.FlarumDiscussions import FlarumDiscussion, FlarumDiscussions
FlarumDiscussion
FlarumDiscussions



#
# POSTS:
#
from pyflarum.classes.flarum.FlarumPosts import FlarumPost
FlarumPost

#
# EXTENSIONS:
#

# Flarum Tags:
from pyflarum.classes.extensions.Flarum_Tags import FlarumPostDiscussionTagsData, FlarumTagUserMixin
FlarumPostDiscussionTagsData
FlarumTagUserMixin

# FoF Polls:
from pyflarum.classes.extensions.FriendsOfFlarum_Polls import FoF_Poll, FoF_PollOption
FoF_Poll
FoF_PollOption



from distutils.core import setup

setup(
    name = 'pyFlarum',
    packages = ['pyflarum'],
    version = 'v0.1-alpha',
    license='GPLv3',
    description = "An unofficial Python package for manipulating with Flarum's API",
    keywords = ['Flarum', 'forum software', 'api', "Flarum api", "bot", "userbot"],

    author = 'Kevo',
    author_email = 'me@kevo.link',

    url = 'https://github.com/CWKevo/pyflarum',
    download_url = 'https://codeload.github.com/CWKevo/pyflarum/zip/v0.1-alpha',

    install_requires=[
        'requests',
        'requests_cache',
    ],

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
